The following people have contributed to this project by submitting pull
requests :tada:

[\@joelostblom](https://github.com/joelostblom),
[\@lwjohnst86](https://github.com/lwjohnst86),
[\@martonvago](https://github.com/martonvago),
[\@signekb](https://github.com/signekb)
